@@ -5,8 +5,9 @@ import spacy
 from sklearn.feature_extraction.text import TfidfVectorizer
 from sklearn.model_selection import train_test_split
 from tqdm.contrib.concurrent import process_map  # or thread_map
-
+from pathlib import Path
 from octis.dataset.dataset import Dataset
+from collections import Counter
 
 """
 Maps the language to its corresponding spacy model
@@ -25,7 +26,7 @@ class Preprocessing:
                  punctuation: str = string.punctuation, remove_numbers: bool = True, lemmatize: bool = True,
                  stopword_list: Union[str, List[str]] = None, min_chars: int = 1, min_words_docs: int = 0,
                  language: str = 'english', split: bool = True, verbose: bool = False, num_processes: int = None,
-                 save_original_indexes=True):
+                 save_original_indexes=True, remove_stopwords_spacy: bool = True):
         """
         init Preprocessing
 
@@ -47,6 +48,7 @@ class Preprocessing:
         :type punctuation: str
         :param remove_numbers: if true, numbers will be removed
         :type remove_numbers: bool
+        :param remove_stopwords_spacy: bool , if true use spacy to remove stopwords (default: true)
         :param lemmatize: if true, words will be lemmatized using a spacy model according to the language that has been
         set (default: true)
         :type lemmatize: bool
@@ -91,22 +93,27 @@ class Preprocessing:
                                                            "following command:\npython -m spacy download " + lang)
         self.split = split
         self.verbose = verbose
+
+        self.remove_stopwords_spacy = remove_stopwords_spacy
+
+        stopwords = []
+        # if stopwords is None then stopwords are not removed
         if stopword_list is None:
-            stopwords = []
             self.remove_stopwords_spacy = False
         else:
+            # if custom list is specified, then we do not use spacy stopwords
             if type(stopword_list) == list:
                 stopwords = set(stopword_list)
                 self.remove_stopwords_spacy = False
+            elif self.remove_stopwords_spacy:
+                assert stopword_list == language
             else:
+                # if remove_stopwords_spacy is false, then use MALLET English stopwords
                 if 'english' in stopword_list:
-                    with open('octis/preprocessing/stopwords/english.txt') as fr:
+                    stop_word_path = Path(__file__).parent.joinpath('stopwords', 'english.txt')
+                    with open(stop_word_path) as fr:
                         stopwords = [line.strip() for line in fr.readlines()]
                         assert stopword_list == language
-                else:
-                    self.remove_stopwords_spacy = True
-                    assert stopword_list == language
-                    stopwords = []
 
         self.stopwords = stopwords
         self.min_chars = min_chars
@@ -154,6 +161,17 @@ class Preprocessing:
                     final_docs.append(new_doc)
                     final_labels.append(label)
                     document_indexes.append(i)
+
+            labels_to_remove = set([k for k, v in dict(Counter(final_labels)).items() if v <= 3])
+            if len(labels_to_remove) > 0:
+                docs = final_docs
+                labels = final_labels
+                document_indexes, final_labels, final_docs = [], [], []
+                for i, doc, label in zip(range(len(docs)), docs, labels):
+                    if label not in labels_to_remove:
+                        final_docs.append(doc)
+                        final_labels.append(label)
+                        document_indexes.append(i)
         else:
             for i, doc in enumerate(docs):
                 vocab = set(vocabulary)
@@ -200,11 +218,11 @@ class Preprocessing:
                                    document_indexes=document_indexes)
         else:
             if self.save_original_indexes:
-                Dataset(final_docs, vocabulary=vocabulary, metadata=metadata, labels=final_labels,
-                        document_indexes=document_indexes)
+                return Dataset(final_docs, vocabulary=vocabulary, metadata=metadata, labels=final_labels,
+                               document_indexes=document_indexes)
             else:
 
-                Dataset(final_docs, vocabulary=vocabulary, metadata=metadata, labels=final_labels)
+                return Dataset(final_docs, vocabulary=vocabulary, metadata=metadata, labels=final_labels)
 
     def filter_words(self, docs):
         if self.vocabulary is not None:
@@ -223,7 +241,7 @@ class Preprocessing:
             self.preprocessing_steps.append('filter words with less than ' + str(self.min_chars) + " character")
             vectorizer = TfidfVectorizer(df_max_freq=self.max_df, df_min_freq=self.min_df, lowercase=self.lowercase,
                                          max_features=self.max_features, stop_words=self.stopwords,
-                                         token_pattern=r"(?u)\b[\w{" + str(self.min_chars) + r",}|\-]+\b")
+                                         token_pattern=r"(?u)\b[\w|\-]{" + str(self.min_chars) + r",}\b")
 
         else:
 
@@ -233,7 +251,7 @@ class Preprocessing:
                                             ' and higher than ' + str(self.max_df))
             self.preprocessing_steps.append('filter words with less than ' + str(self.min_chars) + " character")
             vectorizer = TfidfVectorizer(max_df=self.max_df, min_df=self.min_df, lowercase=self.lowercase,
-                                         token_pattern=r"(?u)\b[\w{" + str(self.min_chars) + r",}|\-]+\b",
+                                         token_pattern=r"(?u)\b[\w|\-]{" + str(self.min_chars) + r",}\b",
                                          stop_words=self.stopwords)
 
         vectorizer.fit_transform(docs)
